@@ -1,10 +1,10 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2012 Index Data
+ * Copyright (C) 1995-2013 Index Data
  * See the file LICENSE for details.
  */
 
 #if HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <string.h>
@@ -43,9 +43,15 @@ static char *get_file(const char *fname, size_t *len)
     *len = ftell(inf);
     if (*len)  /* zero length not considered an error */
     {
+        size_t r;
         buf = xmalloc(*len);
         fseek(inf, 0L, SEEK_SET);
-        (void) fread(buf, 1, *len, inf);
+        r = fread(buf, 1, *len, inf);
+        if (r != *len)
+        {
+            yaz_log(YLOG_FATAL|YLOG_ERRNO, "short fread of %s", fname);
+            exit(1);
+        }
     }
     fclose(inf);
     return buf;
